/* othello.c */

/* Direttive */
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "scacchiera.h"

#define ROW_LENGTH 256


/* Prototipi delle procedure secondarie */

void InterpretaLineaComando (int argc, char *argv[], char *filedati);

/* Esegue le mosse indicate nel file filemosse */
void Othello (Scacchiera S, char *filemosse);


/* Programma principale */
int main (int argc, char *argv[])
{
  /* Parte dichiarativa */
  char filemosse[ROW_LENGTH];
  Scacchiera S;

  /* Parte esecutiva */
  InterpretaLineaComando(argc,argv,filemosse);

  /* Costruisce la configurazione iniziale della scacchiera */
  InizializzaScacchiera(S);

  /* Esegue le mosse indicate nel file filemosse */
  Othello(S,filemosse);

  /* Stampa la scacchiera finale */
  StampaScacchiera(S);

  /* Stampa l'esito del gioco */
  StampaEsito(S);

  return EXIT_SUCCESS;
}


/* Definizione delle procedure secondarie */

void InterpretaLineaComando (int argc, char *argv[], char *filemosse)
{
  if (argc != 2)
  {
    fprintf(stderr,"Errore nella linea di comando!\n");
    exit(EXIT_FAILURE);
  }

  strcpy(filemosse,argv[1]);
}


/* Esegue le mosse indicate nel file filemosse */
void Othello (Scacchiera S, char *filemosse)
{
  FILE *fp_filemosse;
  char mossa[MOVE_LENGTH+1];
  char giocatore;


  fp_filemosse = fopen(filemosse,"r");
  if (fp_filemosse == NULL)
  {
    fprintf(stderr,"File %s non trovato!\n",filemosse);
    exit(EXIT_FAILURE);
  }

  /* Definisce il giocatore che muove per primo */
  giocatore = NERO;

  /* Finche' ci sono mosse, ne legge una */
  while (fscanf(fp_filemosse,"%s",mossa) == 1)
  {
    /* Se e' una sospensione, valuta se davvero non ci sono mosse lecite */
    if (strcmp(mossa,"--") == 0)
      VerificaSospensione(S,giocatore);
    else
    /* Se e' una mossa regolare, valuta se e' corretta e la esegue */
      EsegueMossa(mossa,giocatore,S);

    /* Passa la mano all'altro giocatore */
    if (giocatore == BIANCO)
      giocatore = NERO;
    else
      giocatore = BIANCO;
  }

  fclose(fp_filemosse);
}
